import unittest
import sasktran as sk
import numpy as np


class TestSpecies(unittest.TestCase):
    def setUp(self):
        self.test_altitudes = np.linspace(500, 99500, 100)

    def _basic_access_tests(self, species, clim: sk.Climatology):
        clim.get_parameter(species, 0, 0, self.test_altitudes, 54372)

    def test_aerosol(self):

        values = np.ones_like(self.test_altitudes)
        climatology = sk.SpeciesAerosol(self.test_altitudes, {'SKCLIMATOLOGY_AEROSOL_CM3': values},
                                        {'SKCLIMATOLOGY_LOGNORMAL_MODERADIUS_MICRONS': values * 0.08,
                                         'SKCLIMATOLOGY_LOGNORMAL_MODEWIDTH': values * 1.6}, 'H2SO4')

        climatology.optical_property.calculate_cross_sections(sk.MSIS90(), 0, 0, 1000, 54372, 750)
        self._basic_access_tests('SKCLIMATOLOGY_AEROSOL_CM3', climatology)
        self._basic_access_tests('SKCLIMATOLOGY_LOGNORMAL_MODERADIUS_MICRONS', climatology)
        self._basic_access_tests('SKCLIMATOLOGY_LOGNORMAL_MODEWIDTH', climatology)
